//
//  ScanViewController.m
//  ScaleBleManagerSDK-demo
//
//  Created by 倍泰 on 2017/11/17.
//  Copyright © 2017年 ebelter. All rights reserved.
//

#import "ScanViewController.h"
#import <ScaleBleManagerSDK/ScaleBleManager.h>
#import "TestViewController.h"

@interface ScanViewController ()<UITableViewDelegate,UITableViewDataSource,ScaleBleManagerDelegate>
@property (weak, nonatomic) IBOutlet UITableView *tableView;
@property (nonatomic,strong) NSMutableArray *datasourceArr;
@property (nonatomic,strong) ScaleBleManager *scaleBleManager;
@end

@implementation ScanViewController
static NSString *cellIdt = @"cell";
- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.navigationItem.title = @"scan";
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:cellIdt];
}
- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    if (self.datasourceArr.count) {
        [self.datasourceArr removeAllObjects];
        [self.tableView reloadData];
    }
    
    // 1. 实例化一个ScaleBleManager管理器
    self.scaleBleManager = [ScaleBleManager shareInstance];
    
    // 2. 成为ScaleBleManager的协议对象
    self.scaleBleManager.delegate = self;
    
    // 3. 指定蓝牙名称（非必须）
    [self.scaleBleManager setDeviceBleName:@"truME" hasHeartRate:NO];
    
    // 判断是否有绑定设备
    if ([self.scaleBleManager getBindingDevice]) {
        // 为了方便测试，先解绑一下，重新扫描
        [self.scaleBleManager unBindingDevice];
    }
    
    [self.scaleBleManager changeUnit:EBUnitTypeKG];
}
#pragma mark - ScaleBleManagerDelegate
- (void)scaleBleManager:(ScaleBleManager *)manager cellPhoneBluetoothDidUpdateState:(SBMPhoneBLEState)state
{
    if (state == SBMPhoneBLEStatePoweredOn) {
        // If cellphone's bluetooth is powered on, start to scan for scales.
        [self.scaleBleManager startScan];
    }else{
        NSLog(@"Please turn on your iPhone's bluetooth");
    }
}
- (void)scaleBleManager:(ScaleBleManager *)manager didDiscoverBluetoothDeviceMacAddress:(NSData *)macAddress deviceName:(NSString *)deviceName
{
    if (![self.datasourceArr containsObject:macAddress]) {
        [self.datasourceArr addObject:macAddress];
        [self.tableView reloadData];
    }
}
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSData *macAddr = self.datasourceArr[indexPath.row];
    // 绑定设备
    [self.scaleBleManager bindingDevice:macAddr];
    
    TestViewController *vc = [[TestViewController alloc]init];
    [self.navigationController pushViewController:vc animated:YES];
}
#pragma mark - UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.datasourceArr.count;
}
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdt];
    NSData *macAddr = self.datasourceArr[indexPath.row];
    cell.textLabel.text = [NSString stringWithFormat:@"%@",macAddr];
    return cell;
}

- (NSMutableArray *)datasourceArr
{
    if (!_datasourceArr) {
        _datasourceArr = [NSMutableArray array];
    }
    return _datasourceArr;
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}

@end
