
//
//  TestViewController.m
//  ScaleBleManagerSDK-demo
//
//  Created by 倍泰 on 2017/11/17.
//  Copyright © 2017年 ebelter. All rights reserved.
//

#import "TestViewController.h"
#import <ScaleBleManagerSDK/ScaleBleManager.h>
@interface TestViewController ()<ScaleBleManagerDelegate>
@property (weak, nonatomic) IBOutlet UITextView *logTextView;
@property (weak, nonatomic) IBOutlet UIButton *unbindingButton;
@property (nonatomic,strong) ScaleBleManager *scaleBleManager;
@property (nonatomic,strong) NSData *scannedDeviceMac;
@property (nonatomic,strong) UserInfo *currUser;
@end

@implementation TestViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    NSLog(@"%s",__func__);
    
    self.navigationItem.title = @"ScaleBleManager Demo";
    
    // Show log in the logTextView
//    [self redirectSTD:STDOUT_FILENO];
//    [self redirectSTD:STDERR_FILENO];
}
- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    NSLog(@"%s",__func__);
    
    self.unbindingButton.enabled = NO;
    [self disableCommandButtons];
    
    
    // 1. 实例化一个ScaleBleManager管理器
    self.scaleBleManager = [ScaleBleManager shareInstance];
    
    // 2. 成为ScaleBleManager的协议对象
    self.scaleBleManager.delegate = self;
    
    // 3. 指定蓝牙名称（非必须）
    [self.scaleBleManager setDeviceBleName:@"truME" hasHeartRate:NO];
    
    // 判断是否有绑定设备
    if ([self.scaleBleManager getBindingDevice].length) {
        self.unbindingButton.enabled = YES;
    }
}
- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    
    // 断开连接
    [self.scaleBleManager disconnectDevice];
}
#pragma mark - ScaleBleManagerDelegate
- (void)scaleBleManager:(ScaleBleManager *)manager cellPhoneBluetoothDidUpdateState:(SBMPhoneBLEState)state
{
    NSLog(@"Did Update State: %ld",(long)state);
    if (state == SBMPhoneBLEStatePoweredOn) {
//   If cellphone's bluetooth is powered on, you can start to scan for scales.
//        [self.scaleBleManager startScan];
    }else{
        NSLog(@"Please turn on your iPhone's bluetooth");
    }
}
- (void)scaleBleManager:(ScaleBleManager *)manager didDiscoverBluetoothDeviceMacAddress:(NSData *)macAddress deviceName:(NSString *)deviceName
{
    NSLog(@"Did Discover Bluetooth Device MacAddress:%@, deviceName:%@",macAddress,deviceName);
    self.scannedDeviceMac = macAddress;
}
- (void)scaleBleManagerDidConnectDevice:(ScaleBleManager *)manager deviceType:(BSDeviceType)deviceType
{
    NSLog(@"Did Connect Device: %@",deviceType == BSDeviceTypeHeart ? @"心率体脂秤":@"体脂秤");
}
- (void)scaleBleManagerDidDisconnectDevice:(ScaleBleManager *)manager
{
    NSLog(@"Did Disconnect Device");
    [self disableCommandButtons];
    
// If the device is disconnected, you'd better restart scanning.
//    [self.scaleBleManager startScan];
}
//秤亮屏
- (void)scaleBleManagerDidReceiveScaleAwake:(ScaleBleManager *)manager
{
    NSLog(@"Did Receive Scale Awake");
    // 收到秤唤醒后，需第一时间下发用户信息，以便用户测量
    [manager sendUserInfo:self.currUser];
    
    [self enableCommandButtons];
}
//收到用户信息更新响应
- (void)scaleBleManagerDidReceiveUpdateUserInfoResponse:(ScaleBleManager *)manager
{
    NSLog(@"Receive Update UserInfo Response");
    // 获取离线记录
    [manager sendToRequestOfflineDataWithUserInfo:self.currUser];
}
// 秤息屏
- (void)scaleBleManagerDidReceiveScaleSleep:(ScaleBleManager *)manager
{
    NSLog(@"Did Receive Scale Sleep");
    // 获取离线记录
    [manager sendToRequestOfflineDataWithUserInfo:self.currUser];
}
- (void)scaleBleManager:(ScaleBleManager *)manager didReceiveMeasureWeight:(float)weight unit:(EBUnitType)unit
{
    NSLog(@"Did Receive Weight: %.1f",weight);
    EBUnitType unitType = unit;
    NSString *unitString = @"";
    switch (unitType) {
        case EBUnitTypeKG:
            unitString = @"kg";
            break;
        case EBUnitTypeLB:
            unitString = @"lb";
            break;
        case EBUnitTypeJIN:
            unitString = @"斤";
            break;
        default:
            unitString = @"kg";
            break;
    }
    self.logTextView.text = [NSString stringWithFormat:@"\nweight = %.1f unit = %@",weight,unitString];
}
- (void)scaleBleManager:(ScaleBleManager *)manager didReceiveMeasureResult:(BodyFat *)bodyFat
{
    NSLog(@"Did Receive Measure Result");
    EBUnitType unitType = bodyFat.unit;
    NSString *unitString = @"";
    switch (unitType) {
        case EBUnitTypeKG:
            unitString = @"kg";
            break;
        case EBUnitTypeLB:
            unitString = @"lb";
            break;
        case EBUnitTypeJIN:
            unitString = @"斤";
            break;
        default:
            unitString = @"kg";
            break;
    }
    NSLog(@"\nweight = %.1f unit = %@,\nadiposerate = %.1f %%,\nvisceralfat = %.1f,\nmoisture = %.1f %%,\nboneMineralContent = %.1f kg,\nbmr = %.1f kcal/d,\nbmi = %.1f,\nprotein = %.1f %%,\nresistance = %lu,\nboneMuscle = %.1f kg,\nmuscle = %.1f kg,\nheart rate = %ld,\ntime = %@,\nbodyAge = %ld,\nbodyScore = %ld",bodyFat.weight, unitString, bodyFat.adiposerate,bodyFat.visceralfat,bodyFat.moisture,bodyFat.boneMineralContent,bodyFat.bmr,bodyFat.bmi,bodyFat.protein,(unsigned long)bodyFat.resistance,bodyFat.boneMuscle,bodyFat.muscle,(long)bodyFat.heartRate,bodyFat.time,(long)bodyFat.bodyAge,(long)bodyFat.bodyScore);
    self.logTextView.text = [NSString stringWithFormat:@"\nweight = %.1f unit = %@,\nadiposerate = %.1f %%,\nvisceralfat = %.1f,\nmoisture = %.1f %%,\nboneMineralContent = %.1f kg,\nbmr = %.1f kcal/d,\nbmi = %.1f,\nprotein = %.1f %%,\nresistance = %lu,\nboneMuscle = %.1f kg,\nmuscle = %.1f kg,\nheart rate = %ld,\ntime = %@,\nbodyAge = %ld,\nbodyScore = %ld",bodyFat.weight, unitString, bodyFat.adiposerate,bodyFat.visceralfat,bodyFat.moisture,bodyFat.boneMineralContent,bodyFat.bmr,bodyFat.bmi,bodyFat.protein,(unsigned long)bodyFat.resistance,bodyFat.boneMuscle,bodyFat.muscle,(long)bodyFat.heartRate,bodyFat.time,(long)bodyFat.bodyAge,(long)bodyFat.bodyScore];
    
    // 更新一下用户的体重
    self.currUser.weight = bodyFat.weight;
    // 如果测量结果是测脂有效的，更新一下用户的阻抗值
    if (bodyFat.adiposerate > 0.001) {
        self.currUser.resistance = bodyFat.resistance;
    }
    
    [self.scaleBleManager sendToClearAllUsers];
}
- (void)scaleBleManager:(ScaleBleManager *)manager didReceiveOfflineData:(OfflineBodyFat *)bodyFat
{
    NSLog(@"did Receive Offline Data");
    
    // 不是疑义数据
    if (!bodyFat.isSuspectedData) {
        // 更新一下用户的体重
        self.currUser.weight = bodyFat.weight;
        // 如果测量结果是测脂有效的，更新一下用户的阻抗值
        if (bodyFat.adiposerate > 0.001) {
            self.currUser.resistance = bodyFat.resistance;
        }
    }
}
- (void)scaleBleManagerDidReceiveNoMoreOfflineData:(ScaleBleManager *)manager
{
    NSLog(@"No More OfflineData");
    [manager changeUnit:EBUnitTypeLB];// or EBUnitTypeKG/EBUnitTypeJIN/EBUnitTypeST
}
- (void)scaleBleManagerDidReceiveClearDataResp:(ScaleBleManager *)manager
{
    NSLog(@"Did Receive Clear All User Data Resp");
}
#pragma mark - UI
- (IBAction)unbindingButtonClick:(id)sender {
    
    [self.scaleBleManager unBindingDevice];
}
- (IBAction)sendUserInfoButtonClick:(id)sender {
    
    [self.scaleBleManager sendUserInfo:self.currUser];
}
- (IBAction)getHistoryButtonClick:(id)sender {
    
    [self.scaleBleManager sendToRequestOfflineDataWithUserInfo:self.currUser];
}
- (IBAction)deleteAllUsersButtonClick:(id)sender {
    
    [self.scaleBleManager sendToClearAllUsers];
}
- (IBAction)disconnectButtonClick:(id)sender {
    
    [self.scaleBleManager disconnectDevice];
}
- (IBAction)startScanButtonClick:(id)sender {
    
    if (self.scaleBleManager.bleState == SBMPhoneBLEStatePoweredOn) {
        [self.scaleBleManager startScan];
    }
}
- (IBAction)stopScanButtonClick:(id)sender {
    [self.scaleBleManager stopScan];
}


- (void)enableCommandButtons
{
    for (UIView *subview in self.view.subviews) {
        if (subview.tag >= 100) {
            UIButton *btn = (UIButton *)subview;
            btn.enabled = YES;
        }
    }
}
- (void)disableCommandButtons
{
    for (UIView *subview in self.view.subviews) {
        if (subview.tag >= 100) {
            UIButton *btn = (UIButton *)subview;
            btn.enabled = NO;
        }
    }
}
- (UserInfo *)currUser
{
    if (!_currUser) {
        UserInfo *user = [UserInfo new];
        user.userId = @"12345678912";
//        user.userId = @"00000000000";
        user.age = 53;
        user.gender = UserGenderFemale;
        user.resistance = 443;
        user.weight = 68.9;
        user.height = 166;
        user.roleType = UserRoleTypeSportsman;
        _currUser = user;
    }
    return _currUser;
}
- (void)redirectNotificationHandle:(NSNotification *)nf{ // 通知方法
    NSData *data = [[nf userInfo] objectForKey:NSFileHandleNotificationDataItem];
    NSString *str = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
    
    self.logTextView.text = [NSString stringWithFormat:@"%@\n\n%@",self.logTextView.text, str];// logTextView 就是要将日志输出的视图（UITextView）
    NSRange range;
    range.location = [self.logTextView.text length] - 1;
    range.length = 0;
    [self.logTextView scrollRangeToVisible:range];
    [[nf object] readInBackgroundAndNotify];
}

- (void)redirectSTD:(int )fd{
    NSPipe * pipe = [NSPipe pipe] ;// 初始化一个NSPipe 对象
    NSFileHandle *pipeReadHandle = [pipe fileHandleForReading] ;
    dup2([[pipe fileHandleForWriting] fileDescriptor], fd) ;
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(redirectNotificationHandle:)
                                                 name:NSFileHandleReadCompletionNotification
                                               object:pipeReadHandle]; // 注册通知
    [pipeReadHandle readInBackgroundAndNotify];
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    
}
@end
