//
//  ScanViewController.swift
//  ScaleBleManagerSDK_demo_swift
//
//  Created by 倍泰 on 2020/5/29.
//  Copyright © 2020 ebelter. All rights reserved.
//

import UIKit

class ScanViewController: UIViewController, UITableViewDelegate, UITableViewDataSource, ScaleBleManagerDelegate {
    
    @IBOutlet weak var tableView: UITableView!
    private var datasourceArr = [Data]()
    private var scaleBleManager:ScaleBleManager!
    private let cellIdt = "cell"
    
    override func viewDidLoad() {
        super.viewDidLoad()

        self.navigationItem.title = "scan"
        self.tableView.register(UITableViewCell.classForCoder(), forCellReuseIdentifier: cellIdt)
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        if self.datasourceArr.count > 0 {
            self.datasourceArr.removeAll()
            self.tableView.reloadData()
        }
        
        // 1. 实例化一个ScaleBleManager管理器
        self.scaleBleManager = ScaleBleManager.shareInstance()
        
        // 2. 成为ScaleBleManager的协议对象
        self.scaleBleManager.delegate = self
        
        // 3. 指定蓝牙名称（非必须）
        self.scaleBleManager.setDeviceBleName("YourScaleBluetoothName", hasHeartRate: false);
        
        // 判断是否有绑定设备
        if self.scaleBleManager.getBindingDevice() != nil {
            // 为了方便测试，先解绑一下，重新扫描
            self.scaleBleManager.unBindingDevice()
        }
    }
    
    // MARK: - ScaleBleManagerDelegate
    func scaleBleManager(_ manager: ScaleBleManager!, cellPhoneBluetoothDidUpdate state: SBMPhoneBLEState) {
        if state == SBMPhoneBLEStatePoweredOn {
            // If cellphone's bluetooth is powered on, start to scan for scales.
            self.scaleBleManager.startScan()
        }else{
            print("Please turn on your iPhone's bluetooth")
        }
    }
    
    func scaleBleManager(_ manager: ScaleBleManager!, didDiscoverBluetoothDeviceMacAddress macAddress: Data!, deviceName: String!) {
        if !self.datasourceArr.contains(macAddress) {
            self.datasourceArr.append(macAddress)
            self.tableView.reloadData()
        }
    }

    // MARK: - UITableViewDataSource - UITableViewDelegate
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.datasourceArr.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: cellIdt) ?? UITableViewCell.init(style: .default, reuseIdentifier: cellIdt)
        let macAddr:Data = self.datasourceArr[indexPath.row]
        cell.textLabel?.text = String.init(format: "%@", macAddr as CVarArg)
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let macAddr:Data = self.datasourceArr[indexPath.row];
        // 绑定设备
        self.scaleBleManager.bindingDevice(macAddr)
        
        let testVC = TestViewController()
        self.navigationController?.pushViewController(testVC, animated: true)
    }
}
