//
//  TestViewController.swift
//  ScaleBleManagerSDK_demo_swift
//
//  Created by 倍泰 on 2020/5/29.
//  Copyright © 2020 ebelter. All rights reserved.
//

import UIKit

class TestViewController: UIViewController, ScaleBleManagerDelegate{
    @IBOutlet weak var logTextView: UITextView!
    @IBOutlet weak var unbindingButton: UIButton!
    open var scannedDeviceMac:Data!
    private var scaleBleManager:ScaleBleManager!
    private var currUser = UserInfo()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        self.navigationItem.title = "ScaleBleManager Demo"
        
        self.setUser()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        self.unbindingButton.isEnabled = false
        self.disableCommandButtons()
        
        // 1. 实例化一个ScaleBleManager管理器
        self.scaleBleManager = ScaleBleManager.shareInstance()
        
        // 2. 成为ScaleBleManager的协议对象
        self.scaleBleManager.delegate = self
        
        // 3. 指定蓝牙名称（非必须）
        self.scaleBleManager.setDeviceBleName("YourScaleBluetoothName", hasHeartRate: false);
        
        // 判断是否有绑定设备
        if self.scaleBleManager.getBindingDevice() != nil {
            self.unbindingButton.isEnabled = false;
        }
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
        // 断开连接
        self.scaleBleManager.disconnectDevice()
    }
    
    // MARK: - ScaleBleManagerDelegate
    func scaleBleManager(_ manager: ScaleBleManager!, cellPhoneBluetoothDidUpdate state: SBMPhoneBLEState) {
        print(String.init(format: "Did Update State: %ld",state as! CVarArg))
        if state == SBMPhoneBLEStatePoweredOn {
            // If cellphone's bluetooth is powered on, start to scan for scales.
//            self.scaleBleManager.startScan()
        }else{
            print("Please turn on your iPhone's bluetooth")
        }
    }
    
    func scaleBleManager(_ manager: ScaleBleManager!, didDiscoverBluetoothDeviceMacAddress macAddress: Data!, deviceName: String!) {
        print(String.init(format: "Did Discover Bluetooth Device MacAddress:%@, deviceName:%@",macAddress! as CVarArg,deviceName))
    }
    
    func scaleBleManagerDidConnectDevice(_ manager: ScaleBleManager!, deviceType: BSDeviceType) {
        print(String.init(format: "Did Connect Device: %@",deviceType == BSDeviceTypeHeart ? "心率体脂秤":"体脂秤"))
    }
    
    func scaleBleManagerDidDisconnectDevice(_ manager: ScaleBleManager!) {
        print("Did Disconnect Device")
        self.disableCommandButtons()
    }
    
    func scaleBleManagerDidReceiveScaleAwake(_ manager: ScaleBleManager!) {
        print("Did Receive Scale Awake")
        // 收到秤唤醒后，需第一时间下发用户信息，以便用户测量
        manager.send(self.currUser)
        self.enableCommandButtons()
    }
    
    func scaleBleManagerDidReceiveUpdateUserInfoResponse(_ manager: ScaleBleManager!) {
        print("Receive Update UserInfo Response")
    }
    
    func scaleBleManagerDidReceiveScaleSleep(_ manager: ScaleBleManager!) {
        print("Did Receive Scale Sleep")
    }
    
    func scaleBleManager(_ manager: ScaleBleManager!, didReceiveMeasureWeight weight: Float, unit: EBUnitType) {
        print(String.init(format: "Did Receive Weight: %.1f",weight))
        var unitString = ""
        switch unit {
        case EBUnitTypeKG:
            unitString = "kg"
        case EBUnitTypeLB:
            unitString = "lb"
        case EBUnitTypeJIN:
            unitString = "斤"
        default:
            unitString = "kg"
        }
        self.logTextView.text = String.init(format: "\nweight = %.1f unit = %@",weight,unitString)
    }
    
    func scaleBleManager(_ manager: ScaleBleManager!, didReceiveMeasureResult bodyFat: BodyFat!) {
        print("Did Receive Measure Result")
        var unitString = ""
        switch bodyFat.unit {
        case EBUnitTypeKG:
            unitString = "kg"
        case EBUnitTypeLB:
            unitString = "lb"
        case EBUnitTypeJIN:
            unitString = "斤"
        default:
            unitString = "kg"
        }
        print(String.init(format: "\nweight = %.1f unit = %@,\nadiposerate = %.1f %%,\nvisceralfat = %.1f,\nmoisture = %.1f %%,\nboneMineralContent = %.1f kg,\nbmr = %.1f kcal/d,\nbmi = %.1f,\nprotein = %.1f %%,\nresistance = %lu,\nboneMuscle = %.1f kg,\nmuscle = %.1f kg,\nheart rate = %ld,\ntime = %@,\nbodyAge = %ld,\nbodyScore = %ld",bodyFat.weight,unitString, bodyFat.adiposerate,bodyFat.visceralfat,bodyFat.moisture,bodyFat.boneMineralContent,bodyFat.bmr,bodyFat.bmi,bodyFat.protein,bodyFat.resistance,bodyFat.boneMuscle,bodyFat.muscle,bodyFat.heartRate,bodyFat.time,bodyFat.bodyAge,bodyFat.bodyScore))
        
        self.logTextView.text = String.init(format: "\nweight = %.1f unit = %@,\nadiposerate = %.1f %%,\nvisceralfat = %.1f,\nmoisture = %.1f %%,\nboneMineralContent = %.1f kg,\nbmr = %.1f kcal/d,\nbmi = %.1f,\nprotein = %.1f %%,\nresistance = %lu,\nboneMuscle = %.1f kg,\nmuscle = %.1f kg,\nheart rate = %ld,\ntime = %@,\nbodyAge = %ld,\nbodyScore = %ld",bodyFat.weight,unitString, bodyFat.adiposerate,bodyFat.visceralfat,bodyFat.moisture,bodyFat.boneMineralContent,bodyFat.bmr,bodyFat.bmi,bodyFat.protein,bodyFat.resistance,bodyFat.boneMuscle,bodyFat.muscle,bodyFat.heartRate,bodyFat.time,bodyFat.bodyAge,bodyFat.bodyScore)
        
        // 更新一下用户的体重
        self.currUser.weight = Float(bodyFat.weight)
        // 如果测量结果是测脂有效的，更新一下用户的阻抗值
        if (bodyFat.adiposerate > 0.001) {
            self.currUser.resistance = bodyFat.resistance;
        }
    }
    
    func scaleBleManager(_ manager: ScaleBleManager!, didReceiveOfflineData bodyFat: OfflineBodyFat!) {
        print("did Receive Offline Data")
        // 不是疑义数据
        if (!bodyFat.isSuspectedData) {
            // 更新一下用户的体重
            self.currUser.weight = Float(bodyFat.weight);
            // 如果测量结果是测脂有效的，更新一下用户的阻抗值
            if (bodyFat.adiposerate > 0.001) {
                self.currUser.resistance = bodyFat.resistance;
            }
        }
    }
    
    func scaleBleManagerDidReceiveNoMoreOfflineData(_ manager: ScaleBleManager!) {
        print("No More OfflineData")
        manager.change(EBUnitTypeLB) // or EBUnitTypeKG
    }
    
    func scaleBleManagerDidReceiveClearDataResp(_ manager: ScaleBleManager!) {
        print("Did Receive Clear All User Data Resp")
    }
    
    // MARK: - UI
    @IBAction func unbindingButtonClick(_ sender: Any) {
        // 解绑设备
        self.scaleBleManager.unBindingDevice()
    }
    @IBAction func sendUserInfoButtonClick(_ sender: Any) {
        // 下发用户信息
        self.scaleBleManager.send(self.currUser)
    }
    @IBAction func getHistoryButtonClick(_ sender: Any) {
        // 下发查询离线数据
        self.scaleBleManager.sendToRequestOfflineData(with: self.currUser)
    }
    @IBAction func deleteAllUsersButtonClick(_ sender: Any) {
        // 下发清除设备中所有用户信息
        self.scaleBleManager.sendToClearAllUsers()
    }
    @IBAction func disconnectButtonClick(_ sender: Any) {
        // 断开设备连接
        self.scaleBleManager.disconnectDevice()
    }
    @IBAction func startScanButtonClick(_ sender: Any) {
        // 开始扫描
        if self.scaleBleManager.bleState == SBMPhoneBLEStatePoweredOn {
            self.scaleBleManager.startScan()
        }
    }
    @IBAction func stopScanButtonClick(_ sender: Any) {
        // 停止扫描
        self.scaleBleManager.stopScan()
    }
    
    private func enableCommandButtons() {
        for subView in self.view.subviews {
            if subView.tag >= 100 {
                if subView.isKind(of: UIButton.classForCoder()) {
                    let button = subView as! UIButton
                    button.isEnabled = true
                }
            }
        }
    }
    
    private func disableCommandButtons() {
        for subView in self.view.subviews {
            if subView.tag >= 100 {
                if subView.isKind(of: UIButton.classForCoder()) {
                    let button = subView as! UIButton
                    button.isEnabled = false
                }
            }
        }
    }
    
    private func setUser() {
        currUser.userId = "12345678912"
        currUser.age = 35
        currUser.gender = UserGenderMale
        currUser.resistance = 500
        currUser.weight = 62.6
        currUser.height = 170
        currUser.resistance = 522
        currUser.roleType = UserRoleTypeNormal
    }
}
